@@ -6,14 +6,19 @@ build_404 <- function(pkg = ".") {
 
   if (!file_exists(page_md)) {
     render_page(
-      pkg, "title-body",
+      pkg,
+      "title-body",
       data = list(
         pagetitle = tr_("Page not found (404)"),
         body = tr_("Content not found. Please use links in the navbar.")
       ),
       path = "404.html"
     )
-    update_html(path_abs("404.html", start = pkg$dst_path), tweak_link_absolute, pkg = pkg)
+    update_html(
+      path_abs("404.html", start = pkg$dst_path),
+      tweak_link_absolute,
+      pkg = pkg
+    )
   }
 
   invisible()
