@@ -13,12 +13,14 @@ linkify <- function(text) {
   text <- gsub(
     "&lt;doi:([^&]+)&gt;", # DOIs with < > & are not supported
     "&lt;<a href='https://doi.org/\\1'>doi:\\1</a>&gt;",
-    text, ignore.case = TRUE
+    text,
+    ignore.case = TRUE
   )
   text <- gsub(
     "&lt;arXiv:([^&]+)&gt;",
     "&lt;<a href='https://arxiv.org/abs/\\1'>arXiv:\\1</a>&gt;",
-    text, ignore.case = TRUE
+    text,
+    ignore.case = TRUE
   )
   text <- gsub(
     "&lt;((http|ftp)[^&]+)&gt;", # URIs with & are not supported
