@@ -1,16 +1,18 @@
-tweak_homepage_html <- function(html,
-                                strip_header = FALSE,
-                                sidebar = TRUE,
-                                show_badges = TRUE,
-                                bs_version = 3,
-                                logo = NULL) {
-
+tweak_homepage_html <- function(
+  html,
+  strip_header = FALSE,
+  sidebar = TRUE,
+  show_badges = TRUE,
+  bs_version = 3,
+  logo = NULL
+) {
   html <- tweak_sidebar_html(html, sidebar = sidebar, show_badges = show_badges)
 
   # Always remove dummy page header
   header <- xml2::xml_find_all(html, ".//div[contains(@class, 'page-header')]")
-  if (length(header) > 0)
+  if (length(header) > 0) {
     xml2::xml_remove(header, free = TRUE)
+  }
 
   header <- xml2::xml_find_first(html, ".//h1")
   if (strip_header) {
@@ -22,7 +24,10 @@ tweak_homepage_html <- function(html,
   if (!is.null(logo) && bs_version > 3) {
     # Remove logo if added to h1
     # Bare image
-    xml2::xml_remove(xml2::xml_find_all(html, ".//h1/img[contains(@src, 'logo')]"))
+    xml2::xml_remove(xml2::xml_find_all(
+      html,
+      ".//h1/img[contains(@src, 'logo')]"
+    ))
 
     # Image in link
     xml2::xml_remove(
@@ -32,7 +37,9 @@ tweak_homepage_html <- function(html,
     )
 
     # Add back to header
-    xml2::xml_add_sibling(page_header, "img",
+    xml2::xml_add_sibling(
+      page_header,
+      "img",
       src = logo,
       class = "logo",
       alt = "",
@@ -59,7 +66,10 @@ tweak_sidebar_html <- function(html, sidebar = TRUE, show_badges = TRUE) {
     xml2::xml_remove(dev_status_html)
   } else {
     list <- sidebar_section(tr_("Dev status"), badges)
-    list_html <- xml2::xml_find_first(xml2::read_html(list, encoding = "UTF-8"), ".//div")
+    list_html <- xml2::xml_find_first(
+      xml2::read_html(list, encoding = "UTF-8"),
+      ".//div"
+    )
     xml2::xml_replace(dev_status_html, list_html)
   }
 
@@ -76,23 +86,31 @@ badges_extract <- function(html) {
   if (length(x) == 0) {
     # Find start comment, then all elements after
     # which are followed by the end comment.
-    x <- xml2::xml_find_all(html, "
+    x <- xml2::xml_find_all(
+      html,
+      "
       //comment()[contains(., 'badges: start')][1]
       /following-sibling::*[following-sibling::comment()[contains(., 'badges: end')]]
-    ")
-
+    "
+    )
   }
 
   # then try usethis-readme-like paragraph;
   # where the badges: end comment is inside the paragraph after badges: start
   if (length(x) == 0) {
-    x <- xml2::xml_find_all(html, ".//*/comment()[contains(., 'badges: start')]/following-sibling::p[1]")
+    x <- xml2::xml_find_all(
+      html,
+      ".//*/comment()[contains(., 'badges: start')]/following-sibling::p[1]"
+    )
   }
 
   # finally try first paragraph
   if (length(x) == 0) {
     # BS5 (main) and BS3 (div)
-    x <- xml2::xml_find_first(html, "//main/p|//div[@class='contents col-md-9']/p")
+    x <- xml2::xml_find_first(
+      html,
+      "//main/p|//div[@class='contents col-md-9']/p"
+    )
     strict <- TRUE
   }
 
