@@ -1,4 +1,4 @@
-test_that("adds github/gitlab link when available", {
+test_that("adds github/gitlab/codeberg link when available", {
   pkg <- pkg_navbar()
   expect_snapshot_output(navbar_components(pkg))
 
@@ -28,8 +28,7 @@ test_that("can control articles navbar through articles meta", {
   expect_snapshot(
     navbar_articles(
       pkg(
-        articles = list(list(name = "all", contents = c("a", "b"))
-        )
+        articles = list(list(name = "all", contents = c("a", "b")))
       )
     )
   )
@@ -38,7 +37,11 @@ test_that("can control articles navbar through articles meta", {
   expect_snapshot(
     navbar_articles(
       pkg(
-        articles = list(list(name = "all", contents = c("a", "b"), navbar = NULL))
+        articles = list(list(
+          name = "all",
+          contents = c("a", "b"),
+          navbar = NULL
+        ))
       )
     )
   )
@@ -47,7 +50,11 @@ test_that("can control articles navbar through articles meta", {
   expect_snapshot(
     navbar_articles(
       pkg(
-        articles = list(list(name = "all", contents = c("a", "b"), navbar = "Label"))
+        articles = list(list(
+          name = "all",
+          contents = c("a", "b"),
+          navbar = "Label"
+        ))
       )
     )
   )
@@ -60,18 +67,21 @@ test_that("can control articles navbar through articles meta", {
           list(name = "a", contents = "a", navbar = NULL),
           list(name = "b", contents = "b")
         )
-     )
+      )
     )
   )
-
 })
 
 test_that("can control articles navbar through navbar meta", {
-  pkg <- local_pkgdown_site(meta = list(
-    navbar = list(
-      components = list(articles = menu_submenu("Hi!", list(menu_heading("Hi"))))
+  pkg <- local_pkgdown_site(
+    meta = list(
+      navbar = list(
+        components = list(
+          articles = menu_submenu("Hi!", list(menu_heading("Hi")))
+        )
+      )
     )
-  ))
+  )
   pkg <- pkg_add_file(pkg, "vignettes/a.Rmd", pkg_vignette())
   pkg <- pkg_add_file(pkg, "vignettes/b.Rmd", pkg_vignette())
 
@@ -80,38 +90,44 @@ test_that("can control articles navbar through navbar meta", {
 })
 
 test_that("data_navbar() works by default", {
-  pkg <- local_pkgdown_site(meta = list(
-    repo = list(url = list(home = "https://github.com/r-lib/pkgdown/"))
-  ))
+  pkg <- local_pkgdown_site(
+    meta = list(
+      repo = list(url = list(home = "https://github.com/r-lib/pkgdown/"))
+    )
+  )
   file_touch(path(pkg$src_path, "NEWS.md"))
 
   expect_snapshot(data_navbar(pkg))
 })
 
 test_that("data_navbar() can re-order default elements", {
-  pkg <- local_pkgdown_site(meta = list(
-    repo = list(url = list(home = "https://github.com/r-lib/pkgdown/")),
-    navbar = list(
-      structure = list(
-        left = c("github", "search"),
-        right = "news"
+  pkg <- local_pkgdown_site(
+    meta = list(
+      repo = list(url = list(home = "https://github.com/r-lib/pkgdown/")),
+      navbar = list(
+        structure = list(
+          left = c("github", "search"),
+          right = "news"
+        )
       )
     )
-  ))
+  )
   file_create(path(pkg$src_path, "NEWS.md"))
 
   expect_snapshot(data_navbar(pkg)[c("left", "right")])
 })
 
 test_that("data_navbar() can remove elements", {
-  pkg <- local_pkgdown_site(meta = list(
-    navbar = list(
-      structure = list(
-        left = c("github", "search"),
-        right = list()
+  pkg <- local_pkgdown_site(
+    meta = list(
+      navbar = list(
+        structure = list(
+          left = c("github", "search"),
+          right = list()
+        )
       )
     )
-  ))
+  )
 
   expect_equal(data_navbar(pkg)$right, "")
 })
@@ -120,9 +136,9 @@ test_that("data_navbar() works with empty side", {
   pkg <- local_pkgdown_site(
     meta = list(navbar = list(structure = list(left = list(), right = list())))
   )
-  
-   expect_snapshot(data_navbar(pkg))
- })
+
+  expect_snapshot(data_navbar(pkg))
+})
 
 test_that("data_navbar_() errors with bad yaml specifications", {
   data_navbar_ <- function(...) {
@@ -153,7 +169,7 @@ test_that("for bs4, default bg and type come from bootswatch", {
 
 test_that("render_navbar_links BS3 & BS4 default", {
   x <- list(
-    intro =  menu_link("Get started", "articles/pkgdown.html"),
+    intro = menu_link("Get started", "articles/pkgdown.html"),
     reference = menu_link("Reference", "reference/index.html"),
     articles = menu_submenu(
       "Articles",
@@ -161,7 +177,10 @@ test_that("render_navbar_links BS3 & BS4 default", {
         menu_link("Auto-linking", "articles/linking.html"),
         menu_link("Search", "articles/search.html"),
         menu_link("Metadata", "articles/metadata.html"),
-        menu_link("Customize your pkgdown website", "articles/customization.html"),
+        menu_link(
+          "Customize your pkgdown website",
+          "articles/customization.html"
+        ),
         menu_separator(),
         menu_link("More...", "articles/index.html")
       )
@@ -175,13 +194,19 @@ test_that("render_navbar_links BS3 & BS4 default", {
 
 test_that("dropdowns on right are right-aligned", {
   x <- list(
-    articles = menu_submenu("Articles", list(menu_heading("A"), menu_heading("B")))
+    articles = menu_submenu(
+      "Articles",
+      list(menu_heading("A"), menu_heading("B"))
+    )
   )
   pkg <- list(bs_version = 5)
 
   right <- xml2::read_html(render_navbar_links(x, pkg = pkg, side = "right"))
-  left <-  xml2::read_html(render_navbar_links(x, pkg = pkg, side = "left"))
+  left <- xml2::read_html(render_navbar_links(x, pkg = pkg, side = "left"))
 
-  expect_equal(xpath_attr(right, ".//ul", "class"), "dropdown-menu dropdown-menu-end")
+  expect_equal(
+    xpath_attr(right, ".//ul", "class"),
+    "dropdown-menu dropdown-menu-end"
+  )
   expect_equal(xpath_attr(left, ".//ul", "class"), "dropdown-menu")
 })
